@@ -1,9 +1,8 @@
 from .client.telegramclient import TelegramClient
 from .network import connection
-from .tl import types, functions, custom
 from .tl.custom import Button
 from .tl import patched as _  # import for its side-effects
-from . import version, events, utils, errors
+from . import version, events, utils, errors, types, functions, custom
 
 __version__ = version.__version__
 
